@@ -228,19 +228,18 @@ def setup(no_hooks: bool):
 
     click.echo()
 
-    # Send test notification
-    if click.confirm("Send test notification?", default=True):
-        try:
-            client = RelayClient(config)
-            response = client.send_test_notification()
+    # Send test notification automatically
+    click.echo("Sending test notification...")
+    try:
+        client = RelayClient(config)
+        response = client.send_test_notification()
 
-            if response.get("success"):
-                click.echo("Test notification sent successfully!")
-                click.echo("Check your Apple Watch for the notification.")
-            else:
-                click.echo(f"Error: {response.get('error', 'Unknown error')}")
-        except Exception as e:
-            click.echo(f"Error sending test notification: {str(e)}", err=True)
+        if response.get("success"):
+            click.echo("Test notification sent! Check your Apple Watch.")
+        else:
+            click.echo(f"Error: {response.get('error', 'Unknown error')}")
+    except Exception as e:
+        click.echo(f"Error sending test notification: {str(e)}", err=True)
 
     click.echo()
     click.echo("Setup complete! Claude Code notifications will now be sent to your Watch.")
@@ -264,20 +263,18 @@ def install_hooks():
         click.echo("All hooks are already installed.")
         return
 
-    # Install hooks
-    if click.confirm("Install WatchCode hooks?", default=True):
-        result = installer.install_hooks()
+    # Install hooks automatically
+    click.echo("Installing hooks...")
+    result = installer.install_hooks()
 
-        click.echo()
-        if result["installed"]:
-            click.echo(f"Installed: {', '.join(result['installed'])}")
-        if result["skipped"]:
-            click.echo(f"Already installed: {', '.join(result['skipped'])}")
+    click.echo()
+    if result["installed"]:
+        click.echo(f"Installed: {', '.join(result['installed'])}")
+    if result["skipped"]:
+        click.echo(f"Already installed: {', '.join(result['skipped'])}")
 
-        click.echo()
-        click.echo("Hooks installed successfully!")
-    else:
-        click.echo("Installation cancelled.")
+    click.echo()
+    click.echo("Hooks installed successfully!")
 
 
 @main.command()
